@@ -29,8 +29,8 @@ namespace FSpot {
 			string path;
 			System.IO.FileInfo file_info;
 
-			foreach (Photo p in selection.Items) {
-				path = p.GetVersionPath(p.DefaultVersionId);
+			foreach (IBrowsableItem item in selection.Items) {
+				path = item.DefaultVersionUri.LocalPath;
 				if (System.IO.File.Exists (path)) {
 					file_info = new System.IO.FileInfo (path);
 					total_size += file_info.Length;
@@ -44,7 +44,7 @@ namespace FSpot {
 			Dialog.Modal = false;
 			Dialog.TransientFor = null;
 			
-			size_label.Text = ToHumanReadableSize(total_size);
+			size_label.Text = SizeUtil.ToHumanReadable (total_size);
 
 			thumb_scrolledwindow.Add (view);
 			Dialog.ShowAll ();
@@ -87,8 +87,7 @@ namespace FSpot {
 				foreach (IBrowsableItem photo in selection.Items) {
 					Gnome.Vfs.Uri source;
 					Gnome.Vfs.Uri target = dest.Clone ();
-					bool changed = false;
-					
+
 					//FIXME workaround to have JpegFile loads the image
 					string path = ImageFile.TempPath (photo.DefaultVersionUri.LocalPath);
 					
@@ -97,7 +96,7 @@ namespace FSpot {
  					
 					// if we are rotating the image and the filter changed something
 					// use the new path as the source
-					if (rotate && OrientationFilter.Convert (photo.DefaultVersionUri.LocalPath, path))
+					if (rotate && new Filters.OrientationFilter ().Convert (photo.DefaultVersionUri.LocalPath, path))
 						source = new Gnome.Vfs.Uri (path);
 
 					Gnome.Vfs.XferProgressCallback cb = new Gnome.Vfs.XferProgressCallback (Progress);
@@ -202,30 +201,5 @@ namespace FSpot {
 			progress_dialog = new FSpot.ThreadProgressDialog (command_thread, selection.Count);
 			progress_dialog.Start ();
 		}
-
-		private static string ToHumanReadableSize (long in_size)
-		{
-			string tmp_str = "";
-			float tmp_size = in_size;
-			int k = 0;
-			string[] size_abr = {"bytes", "kB", "MB", "GB", "TB" };
-
-			while (tmp_size > 700) { //it's easier to read 0.9MB than 932kB
-				tmp_size = tmp_size / 1024;
-				k++;
-			}
-
-			if (tmp_size < 7)
-				tmp_str = tmp_size.ToString ("#.##");
-			else if (tmp_size < 70)
-				tmp_str = tmp_size.ToString ("##.#");
-			else
-				tmp_str = tmp_size.ToString ("#,###");
-
-			if (k < size_abr.Length)
-				return tmp_str + " " + size_abr[k];
-			else
-				return in_size.ToString();
-		}
 	}
 }
