@@ -10,7 +10,7 @@ public class ImageView : Layout {
 
 	public static double ZOOM_FACTOR = 1.1;
 
-	protected const double MAX_ZOOM = 5.0;
+	protected const double MAX_ZOOM = 10.0;
 
 	protected double min_zoom = 0.1;
 	protected double MIN_ZOOM {
@@ -27,6 +27,7 @@ public class ImageView : Layout {
 
 	SelectionChangedDelegate selection_holder;
 	SelectionChangedDelegate zoom_holder;
+
 	public ImageView () : base (null, null)
 	{
 		Raw = f_image_view_new ();
@@ -40,6 +41,14 @@ public class ImageView : Layout {
 				       IntPtr.Zero, 0);
 	}
 
+	protected override void OnDestroyed ()
+	{
+		if (selection_holder != null)
+			selection_holder = null;
+
+		if (zoom_holder != null)
+			zoom_holder = null;
+	}
 
 	public enum PointerModeType {
 		None,
@@ -148,7 +157,6 @@ public class ImageView : Layout {
 		image_view_set_zoom (Handle, zoom_x, zoom_y, true, anchor_x, anchor_y);
 	}
 
-
 	[DllImport ("libfspoteog")]
 	static extern void image_view_get_zoom (IntPtr view, out double zoomx, out double zoomy);
 
@@ -211,6 +219,22 @@ public class ImageView : Layout {
 		}
 	}
 
+	[DllImport ("libfspoteog")]
+	static extern void image_view_set_interp_type (IntPtr view, Gdk.InterpType interpolation);
+	
+	[DllImport ("libfspoteog")]
+	static extern Gdk.InterpType image_view_get_interp_type (IntPtr view);
+
+	public Gdk.InterpType Interpolation 
+	{
+		set {
+			image_view_set_interp_type (Handle, value);
+		}
+		get {
+			return image_view_get_interp_type (Handle);
+		}
+	}
+
 
 	[DllImport ("libfspoteog")]
 	static extern void image_view_set_display_contrast (IntPtr view, float display_contrast);
@@ -238,8 +262,6 @@ public class ImageView : Layout {
 			min_zoom = 0.1;
 		}
 
-		System.Console.WriteLine ("min_zoom updated to {0}", min_zoom);
-
 		image_view_update_min_zoom (Handle);
 		
 		// Since this affects the zoom_scale we should alert it
