@@ -143,43 +143,48 @@ namespace FSpot {
 		Gdk.Point start_hot;
 		Gdk.Point pos_hot;
 		Gdk.Point hotspot;
-		double drag_angle;
 
 		public Loupe (PhotoImageView view) : base ("Loupe")
 		{ 
 			this.view = view;
 			Decorated = false;
 			
-			TransientFor = (Gtk.Window) view.Toplevel;
+			Gtk.Window win = (Gtk.Window) view.Toplevel;
+
+			win.GetPosition (out old_win_pos.X, out old_win_pos.Y);
+			win.ConfigureEvent += HandleToplevelConfigure;
+
+			TransientFor = win;
 			DestroyWithParent = true;
 
 			BuildUI ();
 		}
 
+		
+
 		[DllImport("libgdk-2.0-0.dll")]
 	        static extern bool gdk_screen_is_composited (IntPtr screen);
 		
 		[DllImport ("libgtk-win32-2.0-0.dll")]
 		static extern void gtk_widget_input_shape_combine_mask (IntPtr raw, IntPtr shape_mask, int offset_x, int offset_y);
 
-
-		public bool IsComposited 
+		Gdk.Point old_win_pos;
+		[GLib.ConnectBefore]
+		public void HandleToplevelConfigure (object o, ConfigureEventArgs args)
 		{
-			get { 
-#if false
-				try {
-					return gdk_screen_is_composited (Screen.Handle);
-				} catch {
-					//System.Console.WriteLine ("unable to query composite manager");
-				}
-#endif
-				return use_shape_ext;
-			}
-			set {
-				use_shape_ext = ! value;
-			}
-		}
+			int x, y;
+			int loupe_x, loupe_y;
 
+			x = args.Event.X - old_win_pos.X;
+			y = args.Event.Y - old_win_pos.Y;
+			
+			GetPosition (out loupe_x, out loupe_y);
+			Move (loupe_x + x, loupe_y + y);
+
+			old_win_pos.X = args.Event.X;
+			old_win_pos.Y = args.Event.Y;
+		}
+		
 		public void InputShapeCombineMask(Gdk.Pixmap shape_mask, int offset_x, int offset_y)
 		{
 			gtk_widget_input_shape_combine_mask (Handle, shape_mask == null ? IntPtr.Zero : shape_mask.Handle, offset_x, offset_y);
@@ -241,7 +246,7 @@ namespace FSpot {
 
 		protected override void OnRealized ()
 		{
-			use_shape_ext = ! CompositeUtils.SetRgbaColormap (this);
+			use_shape_ext = ! (CompositeUtils.IsComposited (Screen) && CompositeUtils.SetRgbaColormap (this));
 			
 			base.OnRealized ();
 			ShapeWindow ();
@@ -309,20 +314,20 @@ namespace FSpot {
 							    Allocation.Width, 
 							    Allocation.Height, 1);
 			
-			Graphics g = CreateDrawable (bitmap);
+			Context g = CreateDrawable (bitmap);
 			DrawShape (g, Allocation.Width, Allocation.Height);
 			((IDisposable)g).Dispose ();
 
 			if (use_shape_ext)
 				ShapeCombineMask (bitmap, 0, 0);
 			else {
-				Graphics rgba = CreateDrawable (GdkWindow);
+				Context rgba = CreateDrawable (GdkWindow);
 				DrawShape (rgba, Allocation.Width, Allocation.Height);
 				((IDisposable)rgba).Dispose ();
 				try {
 					InputShapeCombineMask (bitmap, 0,0);
-				} catch {
-					//System.Console.WriteLine ("no inut shaping");
+				} catch (EntryPointNotFoundException) {
+					System.Console.WriteLine ("Warning: gtk+ version doesn't support input shapping");
 				}
 			}
 			bitmap.Dispose ();
@@ -348,14 +353,14 @@ namespace FSpot {
 			hotspot.Y = (int) Math.Ceiling (Center.Y + y_proj);
 		}
 		
-		private void DrawShape (Cairo.Graphics g, int width, int height)
+		private void DrawShape (Cairo.Context g, int width, int height)
 		{
 			int inner_x = radius + border + inner;
 			int cx = Center.X;
 			int cy = Center.Y;
 			
 			g.Operator = Operator.Source;
-			g.Color = new Cairo.Color (0,0,0,0);
+			g.Source = new SolidPattern (new Cairo.Color (0,0,0,0));
 			g.Rectangle (0, 0, width, height);
 			g.Paint ();
 
@@ -363,14 +368,14 @@ namespace FSpot {
 			g.Translate (cx, cy);
 			g.Rotate (angle);
 			
-			g.Color = new Cairo.Color (0.2, 0.2, 0.2, .6);
+			g.Source = new SolidPattern (new Cairo.Color (0.2, 0.2, 0.2, .6));
 			g.Operator = Operator.Over;
 			g.Rectangle (0, - (border + inner), inner_x, 2 * (border + inner));
 			g.Arc (inner_x, 0, inner + border, 0, 2 * Math.PI);
 			g.Arc (0, 0, radius + border, 0, 2 * Math.PI);
 			g.Fill ();
 
-			g.Color = new Cairo.Color (0, 0, 0, 1.0);
+			g.Source = new SolidPattern (new Cairo.Color (0, 0, 0, 1.0));
 			g.Operator = Operator.DestOut;
 			g.Arc (inner_x, 0, inner, 0, 2 * Math.PI);
 #if true
@@ -401,14 +406,14 @@ namespace FSpot {
 				g.Arc (0, 0, radius, angle, angle + Math.PI);
 				g.ClosePath ();
 				g.FillPreserve ();
-				g.Color = new Cairo.Color (1.0, 1.0, 1.0, 1.0);
+				g.Source = new SolidPattern (new Cairo.Color (1.0, 1.0, 1.0, 1.0));
 				g.Stroke ();
 			}
 		}
 
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
-			Graphics g = CreateDrawable (GdkWindow);
+			Context g = CreateDrawable (GdkWindow);
 			DrawShape (g, Allocation.Width, Allocation.Height);
 			//base.OnExposeEvent (args);
 			((IDisposable)g).Dispose ();
@@ -461,7 +466,6 @@ namespace FSpot {
 				Vector v2 = new Vector (now);
 
 				double angle = Vector.AngleBetween (v1, v2);
-				drag_angle = angle;
 				
 				Angle = start_angle + angle;
 				return false;	
@@ -515,7 +519,6 @@ namespace FSpot {
 					dragging = true;
 					rotate = (args.Event.State & Gdk.ModifierType.ShiftMask) > 0;
 					start_angle = Angle;
-					drag_angle = 0.0;
 				} else {
 					Angle += Math.PI /8;
 				}
@@ -557,9 +560,9 @@ namespace FSpot {
                 [DllImport ("libcairo-2.dll")]
                 static extern void cairo_user_to_device (IntPtr cr, ref double x, ref double y);
 
-		static void UserToDevice (Graphics g, ref double x, ref double y)
+		static void UserToDevice (Context ctx, ref double x, ref double y)
 		{
-			cairo_user_to_device (g.Handle, ref x, ref y);
+			cairo_user_to_device (ctx.Handle, ref x, ref y);
 		}
 
 		[DllImport("libgdk-2.0-0.dll")]
@@ -568,19 +571,19 @@ namespace FSpot {
 								double        pixbuf_x,
 								double        pixbuf_y);
 
-		static void SetSourcePixbuf (Graphics g, Gdk.Pixbuf pixbuf, double x, double y)
+		static void SetSourcePixbuf (Context ctx, Gdk.Pixbuf pixbuf, double x, double y)
 		{
-			gdk_cairo_set_source_pixbuf (g.Handle, pixbuf.Handle, x, y);
+			gdk_cairo_set_source_pixbuf (ctx.Handle, pixbuf.Handle, x, y);
 		}
 
 		[DllImport("libgdk-2.0-0.dll")]
 		static extern IntPtr gdk_cairo_create (IntPtr raw);
 		
-		public static Cairo.Graphics CreateDrawable (Gdk.Drawable drawable)
+		public static Cairo.Context CreateDrawable (Gdk.Drawable drawable)
 		{
-			Cairo.Graphics g = new Cairo.Graphics (gdk_cairo_create (drawable.Handle));
+			Cairo.Context g = new Cairo.Context (gdk_cairo_create (drawable.Handle));
 			if (g == null) 
-				throw new Exception ("Couldn't create Cairo Graphics!");
+				throw new Exception ("Couldn't create Cairo Context!");
 			
 			return g;
 		}
