@@ -1,6 +1,6 @@
 using System.Net;
 using System;
-using Mono.Posix;
+using Mono.Unix;
 
 namespace FSpot
 {
@@ -40,6 +40,8 @@ namespace FSpot
 		public const string VIEWER_HEIGHT = "/apps/f-spot/ui/viewer_height";
 		public const string VIEWER_MAXIMIZED = "/apps/f-spot/ui/viewer_maximized";
 		public const string VIEWER_SHOW_TOOLBAR = "/apps/f-spot/ui/viewer_show_toolbar";
+		public const string VIEWER_SHOW_FILENAMES = "/apps/f-spot/ui/viewer_show_filenames";
+ 		public const string VIEWER_INTERPOLATION = "/apps/f-spot/viewer/interpolation";
 		
 		public const string SHOW_TOOLBAR = "/apps/f-spot/ui/show_toolbar";
 		public const string SHOW_SIDEBAR = "/apps/f-spot/ui/show_sidebar";
@@ -77,17 +79,26 @@ namespace FSpot
 		public const string EXPORT_PICASAWEB_ROTATE = "/apps/f-spot/export/picasaweb/rotate";
 		public const string EXPORT_PICASAWEB_BROWSER = "/apps/f-spot/export/picasaweb/browser";
 
+		public const string EXPORT_FOLDER_SCALE = "/apps/f-spot/export/folder/scale";
+		public const string EXPORT_FOLDER_SIZE = "/apps/f-spot/export/folder/size";
+		public const string EXPORT_FOLDER_OPEN = "/apps/f-spot/export/folder/browser";
+		public const string EXPORT_FOLDER_ROTATE = "/apps/f-spot/export/folder/rotate";
+		public const string EXPORT_FOLDER_METHOD = "/apps/f-spot/export/folder/method";
+		
  		public const string EXPORT_EMAIL_SIZE = "/apps/f-spot/export/email/size";
  		public const string EXPORT_EMAIL_ROTATE = "/apps/f-spot/export/email/auto_rotate";
  		public const string EXPORT_EMAIL_DELETE_TIMEOUT_SEC = "/apps/f-spot/export/email/delete_timeout_seconds";
 
 		public const string SCREENSAVER_TAG = "/apps/f-spot/screensaver/tag_id";
 
+		public const string STORAGE_PATH = "/apps/f-spot/import/storage_path";
+
 		public const string METADATA_EMBED_IN_IMAGE = "/apps/f-spot/metadata/embed_in_image";
 
 		public const string GNOME_SCREENSAVER_THEME = "/apps/gnome-screensaver/themes";
 		public const string GNOME_SCREENSAVER_MODE = "/apps/gnome-screensaver/mode";
 
+
 		static GConf.Client client;
 		static GConf.NotifyEventHandler changed_handler;
 
@@ -129,26 +140,36 @@ namespace FSpot
 			case SHOW_TIMELINE:
 			case SHOW_TAGS:
 			case SHOW_DATES:
+			case VIEWER_SHOW_FILENAMES:
 			case EXPORT_PICASAWEB_SCALE:
 			case EXPORT_PICASAWEB_ROTATE:
 			case EXPORT_PICASAWEB_BROWSER:
+			case EXPORT_FOLDER_SCALE:
 				return true;
 			
 			case EXPORT_PICASAWEB_SIZE:
+			case EXPORT_FOLDER_SIZE:
 				return 800;
 		
 			case SIDEBAR_POSITION:
 			case ZOOM:
 				return null;
+
 			case SCREENSAVER_TAG:
 				return 1;
-				
+			case STORAGE_PATH:
+				return System.IO.Path.Combine (FSpot.Global.HomeDirectory, Catalog.GetString("Photos"));
 			case EXPORT_EMAIL_SIZE:
 				return 3;	// medium size 640px
 			case EXPORT_EMAIL_ROTATE:
-				return true;	// auto rotate original photos
+			case EXPORT_FOLDER_OPEN:
+			case EXPORT_FOLDER_ROTATE:
+			case VIEWER_INTERPOLATION:
+				return true;
 			case EXPORT_EMAIL_DELETE_TIMEOUT_SEC:
 				return 30;	// delete temporary email pictures after 30 seconds
+			case EXPORT_FOLDER_METHOD:
+				return "static";
 			}
 
 			return null;
@@ -160,7 +181,7 @@ namespace FSpot
 				return Client.Get (key);
 			} catch (GConf.NoSuchKeyException) {
 				if (default_val != null)
-					Client.Set (key, default_val);
+					Set (key, default_val);
 				
 				return default_val;
 			}
@@ -174,7 +195,7 @@ namespace FSpot
 				object default_val = GetDefault (key);
 
 				if (default_val != null)
-					Client.Set (key, default_val);
+					Set (key, default_val);
 
 				return default_val;
 			}
@@ -182,7 +203,21 @@ namespace FSpot
 
 		public static void Set (string key, object value)
 		{
-			Client.Set (key, value);
+			try {
+				Client.Set (key, value);
+			} catch {
+				Console.WriteLine ("Unable to write this gconf key :"+key);
+			}
+		}
+
+		public static void SetAsBackground (string path)
+		{
+			Client.Set ("/desktop/gnome/background/color_shading_type", "solid");
+			Client.Set ("/desktop/gnome/background/primary_color", "#000000");
+			Client.Set ("/desktop/gnome/background/picture_options", "stretched");
+			Client.Set ("/desktop/gnome/background/picture_opacity", 100);
+			Client.Set ("/desktop/gnome/background/picture_filename", path);
+			Client.Set ("/desktop/gnome/background/draw_background", true);
 		}
 
 		public static event GConf.NotifyEventHandler SettingChanged;
@@ -231,7 +266,7 @@ namespace FSpot
 				string password = (string) Preferences.Get (PaswordKey, "");
 
 				proxy.Credentials = new NetworkCredential (username, password);
-			} catch (Exception e) {
+			} catch (Exception) {
 				proxy = null;
 			}
 
