@@ -17,11 +17,15 @@ using Gtk;
 using Gnome;
 using System;
 
+using FSpot.Filters;
+using Mono.Unix;
+
 namespace FSpot {
 	public class SendEmail : FSpot.GladeDialog {
 		PhotoQuery query;
 		Gtk.Window parent_window;
 
+		[Glade.Widget] private ScrolledWindow   tray_scrolled;
 		[Glade.Widget] private Button 		ok_button;
 		[Glade.Widget] private Label 		NumberOfPictures, TotalOriginalSize, ApproxNewSize;	
 		[Glade.Widget] private RadioButton 	tiny_size, small_size, medium_size, 
@@ -30,10 +34,8 @@ namespace FSpot {
 
 		int photo_index;
 		bool clean;
-		static uint timer = 0;
 		long Orig_Photo_Size 	= 0;
 		double scale_percentage = 0.3;
-		bool keep_exif 		= true;
 		
 		// The different sizes we can shrink to foto to. See RadioButton above for labels.
 		static int[] sizes 		= { 0, 320, 	480, 	640, 	800, 	1024 };
@@ -66,12 +68,9 @@ namespace FSpot {
 			}
 			rotate_check.Active = (bool) Preferences.Get (Preferences.EXPORT_EMAIL_ROTATE);
 			
-			IconView view = new IconView (selection);
-			view.DisplayDates = false;
-			view.DisplayTags = false;
+			tray_scrolled.Add (new TrayView (selection));
 
 			Dialog.Modal = false;
-			Dialog.TransientFor = null;
 
 			string path;
 			System.IO.FileInfo file_info;
@@ -129,11 +128,10 @@ namespace FSpot {
 			}
 
 			NumberOfPictures.Text 	= selection.Count.ToString();
-			TotalOriginalSize.Text 	= ToHumanReadableSize (Orig_Photo_Size);
+			TotalOriginalSize.Text 	= SizeUtil.ToHumanReadable (Orig_Photo_Size);
 			
 			UpdateEstimatedSize();
 
-			//thumb_scrolledwindow.Add (view);
 			Dialog.ShowAll ();
 
 			//LoadHistory ();
@@ -141,31 +139,6 @@ namespace FSpot {
 			Dialog.Response += HandleResponse;
 		}
 
-		private static string ToHumanReadableSize (long in_size)
-		{
-			string tmp_str = "";
-			float tmp_size = in_size;
-			int k = 0;
-			string[] size_abr = {"bytes", "kB", "MB", "GB", "TB" };
-
-			while (tmp_size > 700) { //it's easier to read 0.9MB than 932kB
-				tmp_size = tmp_size / 1024;
-				k++;
-			}
-
-			if (tmp_size < 7)
-				tmp_str = tmp_size.ToString ("0.##");
-			else if (tmp_size < 70)
-				tmp_str = tmp_size.ToString ("##.#");
-			else
-				tmp_str = tmp_size.ToString ("#,###");
-
-			if (k < size_abr.Length)
-				return tmp_str + " " + size_abr[k];
-			else
-				return in_size.ToString();
-                }
-		
 		private int GetScaleSize()
 		{
 			// not only convert dialog size to pixel size, but also set preferences se we use same size next time
@@ -206,7 +179,7 @@ namespace FSpot {
 				else
 					new_approx_total_size = System.Convert.ToInt64(Orig_Photo_Size * avg_scale [new_size_index]);
 
-				approxresult = ToHumanReadableSize (new_approx_total_size);
+				approxresult = SizeUtil.ToHumanReadable (new_approx_total_size);
 				ApproxNewSize.Text 	= approxresult;	
 
 		}
@@ -242,8 +215,6 @@ namespace FSpot {
 
 		private void HandleResponse (object sender, Gtk.ResponseArgs args)
 		{
-			string tmp_path;
-
 			long new_size = 0;
 //			long orig_size = 0;
 			long actual_total_size = 0;
@@ -261,11 +232,10 @@ namespace FSpot {
 			ProgressDialog progress_dialog = null;
 			actual_total_size = 0;
 		
-			progress_dialog = new ProgressDialog (
-						Mono.Posix.Catalog.GetString ("Preparing email"),
-						ProgressDialog.CancelButtonType.Stop,
-						selection.Items.Length, 
-						parent_window);
+			progress_dialog = new ProgressDialog (Catalog.GetString ("Preparing email"),
+							      ProgressDialog.CancelButtonType.Stop,
+							      selection.Items.Length, 
+							      parent_window);
 			
 			size = GetScaleSize(); // Which size should we scale to. 0 --> Original
 			
@@ -282,13 +252,21 @@ namespace FSpot {
 			
 			System.Text.StringBuilder url = new System.Text.StringBuilder ("mailto:?subject=my%20photos");
 
+			FilterSet filters = new FilterSet ();
+
+			if (size != 0)
+				filters.Add (new ResizeFilter ((uint)size));
+			else if (rotate)
+				filters.Add (new OrientationFilter ());
+
+
 			foreach (Photo photo in selection.Items) {
 			
 				if ( (photo != null) && (!UserCancelled) ) {
 
 					if (progress_dialog != null)
 						UserCancelled = progress_dialog.Update (String.Format 
-							(Mono.Posix.Catalog.GetString ("Exporting picture \"{0}\""), photo.Name));
+							(Catalog.GetString ("Exporting picture \"{0}\""), photo.Name));
 							
 					if (UserCancelled)
 					 	break;
@@ -297,52 +275,23 @@ namespace FSpot {
 //					orig_size = file_info.Length;
 
 					// Prepare a tmp_mail file name
-					tmp_path =  FileImportBackend.UniqueName (
-						tmp_mail_dir,
-						System.IO.Path.GetFileName(photo.GetVersionPath(photo.DefaultVersionId))
-						);
+					string orig = photo.DefaultVersionUri.LocalPath;
+					string final = FileImportBackend.UniqueName (tmp_mail_dir,
+							System.IO.Path.GetFileName(photo.GetVersionPath(photo.DefaultVersionId))) + ".jpg";
 
-					if (size == 0) {
-						// User wants to send original photos, no resizing required.
-						if (rotate) {
-							Exif.ExifData exif_data = new Exif.ExifData (photo.GetVersionPath(photo.DefaultVersionId));
-							PixbufOrientation orientation = PixbufUtils.GetOrientation (exif_data);
-							if (orientation == PixbufOrientation.RightTop) {
-								JpegUtils.Transform (photo.GetVersionPath(photo.DefaultVersionId), tmp_path, JpegUtils.TransformType.Rotate90);
-								tmp_paths.Add (tmp_path);
-							} else if (orientation == PixbufOrientation.LeftBottom) {
-								JpegUtils.Transform (photo.GetVersionPath(photo.DefaultVersionId), tmp_path, JpegUtils.TransformType.Rotate270);
-								tmp_paths.Add (tmp_path);
-							} else
-								tmp_path = photo.GetVersionPath(photo.DefaultVersionId);
-						} else {
-							// No need to rotate
-							tmp_path = photo.GetVersionPath(photo.DefaultVersionId);
-						}
-					} else {
-						// resize (including rotate) original photo, and put result in tmp_photo file
-						PixbufUtils.Resize (
-							photo.GetVersionPath(photo.DefaultVersionId),
-							tmp_path, 
-							size, 
-							keep_exif);
+					if (!filters.Convert (orig, final))
+						final = orig;
 
-						// tmp_path = PixbufUtils.Resize (photo.GetVersionPath(photo.DefaultVersionId), size, keep_exif);
-						tmp_paths.Add (tmp_path); // Keep the new tmp_path, so we can delete it later
-					}
-
-					System.Console.WriteLine ("Scaling photo {0}", tmp_path);				
-
-					url.Append ("&attach=" + tmp_path);
+					url.Append ("&attach=" + final);
 					
 					// Update the running total of the actual file sizes.
-					file_info = new System.IO.FileInfo (tmp_path);
+					file_info = new System.IO.FileInfo (final);
 					new_size = file_info.Length;
 					actual_total_size += new_size;
 
 					// Update dialog to indicate Actual size!
 					// This is currently disabled, since the dialog box is not visible at this stage.
-					// string approxresult = ToHumanReadableSize (actual_total_size);
+					// string approxresult = SizeUtil.ToHumanReadable (actual_total_size);
 					// ActualMailSize.Text = approxresult;	
 
 
@@ -369,7 +318,7 @@ namespace FSpot {
 					delete_timeout = delete_timeout * 1000; // to get milliseconds.
 
 					// Start a timer and when it occurs, delete the temp files.
-					timer = GLib.Timeout.Add (delete_timeout, new GLib.TimeoutHandler (DeleteTempFile));
+					GLib.Timeout.Add (delete_timeout, new GLib.TimeoutHandler (DeleteTempFile));
 				}
 			}
 		}
